from google.cloud import storage

def gcs_upload(gcp_project, gcs_bucket, gcs_file_path, local_file_path):
    """
    Upload a local local to google cloud storage
    """
    
    # create conncetion
    client = storage.Client(gcp_project)
    bucket = client.bucket(gcs_bucket)
    # upload
    blob = bucket.blob(gcs_file_path)
    blob.upload_from_filename(local_file_path)
    
    # INCLUIR LOGS
    
    
    
def gcs_download(gcp_project, gcs_bucket, gcs_file_path, local_file_path):
    """
    Downloads a google cloud storage file
    """
 
    # create conncetion
    storage_client = storage.Client(gcp_project)
    bucket = storage_client.bucket(gcs_bucket)
    # download
    blob = bucket.blob(gcs_file_path)
    blob.download_to_filename(local_file_path)
 
    # INCLUIR LOGS
    
    


import pandas as pd

def df_from_bigquery(query, gcp_project, gcs_bucket, gcs_file_path, local_file_path, mode='csv'):
    
    df = pd.read_gbq(query, gcp_project)
    
    if mode == 'csv':
        df.to_csv(local_file_path)
    elif mode == 'parquet':
        df.to_parquet(local_file_path)
        
    gcs_upload(gcp_project, gcs_bucket, gcs_file_path, local_file_path)
    
    return df


from setuptools import setup, find_packages

VERSION = "0.0.3"

setup(
    name="tc-data-tools",
    version=VERSION,
    description="Data tools to help our daily job",
    url="https://github.com/ciro-tc/tc-data-tools",
    author="TC Data Science",
    author_email="ciro.oliveira@tc.com.br",
    license="MIT",
    packages=find_packages(),
    install_requires=[
        "pandas==1.2.4",
        "pandas-gbq==0.15.0",
        "google-cloud-bigquery==2.15.0",
        "google-cloud-storage==1.38.0",
    ],
    classifiers=[
        "Development Status :: 2 - Pre-Alpha",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
    ],
)
